<?php

/**
 * @file
 * Admin page callback file for the follow and unfollow module.
 */

/**
 * Admin setting form.
 */
function follow_unfollow_admin_setting_form($form, &$form_state) {
  $form['content_type'] = array(
    '#type' => 'fieldset',
    '#title' => t('Select Content Types'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );

  $content_type_list = follow_unfollow_get_content_type();
  $form['content_type']['follow_unfollow_content_type'] = array(
    '#type' => 'checkboxes',
    '#required' => TRUE,
    '#title' => t('Content Types'),
    '#options' => $content_type_list,
    '#default_value' => variable_get('follow_unfollow_content_type', array()),
    '#description' => t('Select content type that is used to collect statistics of follow and unfollow content'),
  );

  $form['vocabulary_type'] = array(
    '#type' => 'fieldset',
    '#title' => t('Select Vocabulary Types'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );

  $vocabulary_list = follow_unfollow_get_taxonomy_type();
  $form['vocabulary_type']['follow_unfollow_vocabulary_type'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Vocabulary Types'),
    '#options' => $vocabulary_list,
    '#default_value' => variable_get('follow_unfollow_vocabulary_type', array()),
    '#description' => t('Select Vocabulary type that is used to collect statistics of follow and unfollow content'),
  );

  $form['follow_unfollow_user'] = array(
    '#type' => 'checkbox',
    '#title' => t('Select User Type'),
    '#description' => t('Select User type that is used to collect statistics of follow and unfollow content.'),
    '#default_value' => variable_get('follow_unfollow_user'),
  );

  $form['follow_unfollow_email_template_of_follow'] = array(
    '#type' => 'fieldset',
    '#title' => t('Follow Email Template'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );

  $form['follow_unfollow_email_template_of_follow']['follow_unfollow_subject_of_follow'] = array(
    '#type' => 'textfield',
    '#title' => t('Follow Subject'),
    '#default_value' => variable_get('follow_unfollow_subject_of_follow'),
    '#description' => t('Used @title,@username and @url for follow subject email templating.'),
  );

  $form['follow_unfollow_email_template_of_follow']['follow_unfollow_body_of_follow'] = array(
    '#type' => 'text_format',
    '#title' => t('Follow Body'),
    '#default_value' => variable_get('follow_unfollow_body_of_follow'),
    '#description' => t('Used @title,@username and @url for follow body email templating.'),
    '#wysiwyg' => TRUE,
  );

  $form['follow_unfollow_email_template_of_unfollow'] = array(
    '#type' => 'fieldset',
    '#title' => t('Unfollow Email Template'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );

  $form['follow_unfollow_email_template_of_unfollow']['follow_unfollow_subject_of_unfollow'] = array(
    '#type' => 'textfield',
    '#title' => t('Unfollow Subject'),
    '#default_value' => variable_get('follow_unfollow_subject_of_unfollow'),
    '#description' => t('Used @title,@username and @url for unfollow subject email templating.'),
  );

  $form['follow_unfollow_email_template_of_unfollow']['follow_unfollow_body_of_unfollow'] = array(
    '#type' => 'textarea',
    '#title' => t('Unfollow Body'),
    '#default_value' => variable_get('follow_unfollow_body_of_unfollow'),
    '#description' => t('Used @title,@username and @url for unfollow body email templating.'),
  );

  return system_settings_form($form);
}

/**
 * Get Content type list.
 */
function follow_unfollow_get_content_type() {
  $content_type = node_type_get_types();
  $checklist_content_type_array = array();
  foreach ($content_type as $item) {
    $key = $item->orig_type;
    $value = $item->name;
    $checklist_content_type_array[$key] = $value;
  }
  return $checklist_content_type_array;
}

/**
 * Get Vocabulary list.
 */
function follow_unfollow_get_taxonomy_type() {
  $vocabulary = taxonomy_get_vocabularies();
  $checklist_vocab_array = array();
  foreach ($vocabulary as $item) {
    $key = $item->vid;
    $value = $item->name;
    $checklist_vocab_array[$key] = $value;
  }
  return $checklist_vocab_array;
}
